/*
 * Copyright (C) 1999-2000 Robin Watts/Justin Fletcher
 */

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>

#include "error.h"
#include "options.h"
#include "format.h"
#include "readfile.h" /* For fields */
#include "filename.h"

#include "VersionNum" /* CVS maintained version numbers */

void WriteBlank(void) {

  FILE *file;
  field_t *field;

  if (!opt.blank)
    return;

  /* We check both forms of the name do not exist before trying to create
     the blank file. */
  file=fopen(opt.infile,"r");
  if (file==NULL)
  {
    const char *altname;
    altname = filename_unixtoriscos(opt.infile, EXTLIST_NORCROFT_CMHG);
    file = fopen(altname, "r");
  }
  if (file!=NULL)
    ErrorFatal("File %s already exists - not overwriting",opt.infile);

  printf("Generating blank CMHG template\n");

  file=fopen(opt.infile,"w");
  if (file==NULL)
  {
    const char *altname;
    altname = filename_unixtoriscos(opt.infile, EXTLIST_NORCROFT_CMHG);
    file = fopen(altname, "w");
  }
  if (file==NULL)
    ErrorFatal("Cannot write blank template %s",opt.infile);

  format_wrap(file, "; ",
                    "; ",
"CMHG template, generated by CMunge " Module_FullVersionAndDate "\n"
"\n"
"Customise this to fit the module you are writing",
                    "\n\n");

  field=fields;

  while (field->name)
  {
    if (field->values.type != ft_alias)
    {
      if ( (opt.cmhg && (field->hgtype & IN_CMHG)) ||
           (!opt.cmhg && (field->hgtype & IN_CMUNGE)) )
      {
        format_wrap(file, "; ",
                          "; ", field->blank.comment,
                          "");
        if (field->blank.func)
          field->blank.func(file);

        fprintf(file,"%s: %s\n\n",field->name,field->blank.value);
      }
    }
    field++;
  }
  fclose(file);
  exit(EXIT_SUCCESS); /* And exit NOW because we can't do any more processing */
}


/* Special case for the command-keyword-table so that we can write out all
   its options. */
void blank_commands(FILE *file)
{
  cmdfield_t *field;

  field=cmdfields;

  while (field->name)
  {
    if (field->values.type != ft_alias)
    {
      if ( (opt.cmhg && (field->hgtype & IN_CMHG)) ||
           (!opt.cmhg && (field->hgtype & IN_CMUNGE)) )
      {
        fprintf(file,";   %s: %s\n",field->name,field->blank.value);
        format_wrap(file, ";     ",
                          ";     ", field->blank.comment,
                          "");
      }
    }
    field++;
  }

}
